from bs4 import BeautifulSoup
import os
import urllib
import webbrowser
import time
import authenticate as auth
import prettify as pr
import getpass as gp
import platform as pf


def get_ctime(file):
    attr_list = []
    fl_stat = os.stat(file)
    attr_list = time.ctime(fl_stat.st_ctime).split() 
    return attr_list[2] + "-" + attr_list[3]


def main(email,password,cour_id,new_dir):        
    url = "https://class.coursera.org/"+ cour_id + "/lecture"    
    coursera_session = auth.auth_me(email,password)
    if coursera_session == -1:
        print "Login failed!"
        return
    
    cont = coursera_session.get(url, timeout=30)
    soup = BeautifulSoup(cont.text, 'html.parser')
        
    week_tags=[]
    for week in soup.find_all("div",{"class":"course-item-list-header"}):
        week_tags.append(((week.find("h3").text).strip()).encode("utf-8"))
        
    if len(week_tags) == 0:
	print "Either incorrect course ID or you are not enrolled in that course!"
	print "(Make sure you have accepted the Honor Code of that course)"
	return  
    
    os.chdir(new_dir+"/Desktop")
    os.mkdir(cour_id)
    os.chdir(cour_id)
    
    
    
    index = 0 
    tot_files=0
    time_attr = time.ctime().split()
    st_time = time_attr[2] + "-" + time_attr[3]
    
    for week in (soup.find_all("ul",{"class":"course-item-list-section-list"})):     
        cour_ind=1
        print     
        print "Entered Week No :",index
        print "#####################"    
        os.mkdir(week_tags[index])
        os.chdir(week_tags[index])   
        
        for data in week.find_all("li"):
            tag = str(cour_ind) + ". " + (data.find("a").text).strip()
            tag=tag.replace("/","-")
            print "Downloading Lecture :",tag
            cour_ind+=1
            try:
                os.mkdir(tag)
                os.chdir(tag)
                loc = os.getcwd()
            except:
                pass
            len_links = len(data.find("div").find_all("a"))
            odd = 0
            for link in (data.find("div").find_all("a"))[len_links-2:len_links]:
                url = link.get("href")
                if odd == 0:
                    urllib.urlretrieve(url,loc+"/subtitle.srt")
                    tot_files+=1
                    odd+=1
                else:                    
                    webbrowser.open(url)
                    time.sleep(2)               
                    
                
            os.chdir("..")
        
        index = index + 1
        os.chdir("..")
        time.sleep(4)
    
    path = new_dir + "/Downloads/"
    to_save = new_dir + "/Desktop/" + cour_id + "/"   
    print 
    print "Downloading of files will take some time, depending on your internet."
    print 
    
    file_count = 0
    while(file_count < tot_files):
        file_count=0
        for fl in os.listdir(path):
            if get_ctime(path + fl) > st_time:
                file_count+=1
        time.sleep(15)    
    
    print "All files downloaded." 
    pr.prettify(st_time,path, to_save, week_tags)
    print "A course folder with the name "+ cour_id + " is created on your desktop."
    print "Thank you for using EasyCoursera. Happy to Help :)"
    

def start():
    
    print "\n**Make sure you are logged in to your Coursera Account from your default web browser**\n"
    email = str(raw_input("Enter registered email address : "))    
    password = str(gp.getpass("Enter password (Typing will be hidden): "))    
    cour_id = str(raw_input("Enter Coursera Course ID : ")) 
    print 
    
    cur_os = pf.system()
    cur_user = gp.getuser()
    if cur_os == "Windows":
    	new_dir = "C:/Users/"+cur_user
    else:
    	new_dir = "/home/"+cur_user

    
    main(email, password, cour_id, new_dir)
    



import requests
from bs4 import BeautifulSoup
import string
import random
 

def auth_me(email,password):
    
    user_agent = ("Mozilla/5.0 (X11; Linux x86_64) "
                  "AppleWebKit/537.36 (KHTML, like Gecko) "
                  "Ubuntu Chromium/41.0.2272.76 Chrome/41.0.2272.76 Safari/537.36") 
 
    
    def randomCookie(length):
        return ''.join(random.choice(string.letters + string.digits) for i in xrange(length))
     
     
    def make_soup(url):
        html = requests.get(url)
        soup = BeautifulSoup(html.content)
        return soup
        
    signin_link = "https://accounts.coursera.org/api/v1/login"
    signin_info = {"email": email,
                     "password": password,
                     "webrequest": "true"
                     }
     
    XCSRF2Cookie = 'csrf2_token_%s' % ''.join(randomCookie(8))
    XCSRF2Token = ''.join(randomCookie(24))
    XCSRFToken = ''.join(randomCookie(24))
    cookie = "csrftoken=%s; %s=%s" % (XCSRFToken, XCSRF2Cookie, XCSRF2Token)
    post_headers = {"User-Agent": user_agent,
                        "Referer": "https://accounts.coursera.org/signin",
                        "X-Requested-With": "XMLHttpRequest",
                        "X-CSRF2-Cookie": XCSRF2Cookie,
                        "X-CSRF2-Token": XCSRF2Token,
                        "X-CSRFToken": XCSRFToken,
                        "Cookie": cookie
                        }
        
    coursera_session = requests.Session()
        
        
        
    login_res = coursera_session.post(signin_link,
                                              data=signin_info,
                                              headers=post_headers,
                                              )
        
    if login_res.status_code == 200:
        return coursera_session
    else:
        return -1
        


import os
import time

def get_ctime(file):
    attr_list = []
    fl_stat = os.stat(file)
    attr_list = time.ctime(fl_stat.st_ctime).split()
    return attr_list[2] + "-" + attr_list[3]


def prettify(st_time,path, to_save, week_tags):
        
        int_ind = int(sorted(os.listdir(path))[0][0])
        i = int_ind
        fold_index = 0    
        while(i <= (int_ind + len(week_tags) -1)):
            sub_fold_index = 0
            for file in sorted(os.listdir(path)):         
                 des_path = sorted(os.listdir(to_save+week_tags[fold_index]))
                 if file.endswith(".mp4") and file.startswith(str(i)+" -"):
                     os.rename(path+file,to_save+week_tags[fold_index]+"/"+des_path[sub_fold_index]+"/"+file)
                     sub_fold_index+=1
            i+=1
            fold_index += 1





 
       



from distutils.core import setup

setup(name='easy_coursera',
      version='1.0.2',
      description='Download all lecture videos with a single click!',
      url='https://github.com/beingcooper/EasyCoursera',
      author='Sachin Sharma',
      author_email='sachin.sharma0728@gmailcom',
      license='MIT',
      packages=['easy_coursera'])
  